/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#include "host/pinginterval.h"

#include "boost_assert_handler.h"

//-----------------------------------------------------------------------------
// PingInterval
//-----------------------------------------------------------------------------

PingInterval::PingInterval(
        PingIntervalType interval
) :
    OriginalInterval( interval ),
    Interval( interval )
{
    BOOST_ASSERT( 0 < interval );
}

PingInterval::~PingInterval()
{
}

PingInterval::operator PingIntervalType() const
{
    BOOST_ASSERT( 0 < Interval );

    return Interval;
}

void PingInterval::back_to_original()
{
    Interval = OriginalInterval;

    BOOST_ASSERT( 0 < Interval );
}

void PingInterval::speed_up()
{
    BOOST_ASSERT( 0 < Interval );

    if ( can_speed_up() )
    {
        Interval = Interval / 2;
    }

    if ( Interval < 1 )
    {
        Interval = 1;
    }

    BOOST_ASSERT( 0 < Interval );
}

bool PingInterval::can_speed_up() const
{
    PingIntervalType half_original = OriginalInterval / 2;

    return ( Interval > half_original );
}
